AnnotateTextRequest_Features class final

All available features. Setting each one to true will enable that specific analysis for the input.

Constructors

AnnotateTextRequest_Features({bool extractEntities = false, bool extractDocumentSentiment = false, bool classifyText = false, bool moderateText = false})
AnnotateTextRequest_Features.fromJson(Object? j)
factory

Properties

classifyText → bool
Optional. Classify the full document into categories.
final
extractDocumentSentiment → bool
Optional. Extract document-level sentiment.
final
extractEntities → bool
Optional. Extract entities.
final
hashCode → int
The hash code for this object.
no setterinherited
moderateText → bool
Optional. Moderate the document for harmful and sensitive categories.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String