AnnotateTextResponse class final

The text annotations response message.

Constructors

AnnotateTextResponse({List<Sentence> sentences = const [], List<Entity> entities = const [], Sentiment? documentSentiment, String languageCode = '', List<ClassificationCategory> categories = const [], List<ClassificationCategory> moderationCategories = const [], bool languageSupported = false})
AnnotateTextResponse.fromJson(Object? j)
factory

Properties

categories → List<ClassificationCategory>
Categories identified in the input document.
final
documentSentiment → Sentiment?
The overall sentiment for the document. Populated if the user enables AnnotateTextRequest.Features.extract_document_sentiment.
final
entities → List<Entity>
Entities, along with their semantic information, in the input document. Populated if the user enables AnnotateTextRequest.Features.extract_entities or AnnotateTextRequest.Features.extract_entity_sentiment.
final
hashCode → int
The hash code for this object.
no setterinherited
languageCode → String
The language of the text, which will be the same as the language specified in the request or, if not specified, the automatically-detected language. See Document.language field for more details.
final
languageSupported → bool
Whether the language is officially supported by all requested features. The API may still return a response when the language is not supported, but it is on a best effort basis.
final
moderationCategories → List<ClassificationCategory>
Harmful and sensitive categories identified in the input document.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sentences → List<Sentence>
Sentences in the input document. Populated if the user enables AnnotateTextRequest.Features.extract_document_sentiment.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String