ClassificationCategory class final

Represents a category returned from the text classifier.

Constructors

ClassificationCategory({String name = '', double confidence = 0, double severity = 0})
ClassificationCategory.fromJson(Object? j)
factory

Properties

confidence → double
The classifier's confidence of the category. Number represents how certain the classifier is that this category represents the given text.
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
The name of the category representing the document.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
severity → double
Optional. The classifier's severity of the category. This is only present when the ModerateTextRequest.ModelVersion is set to MODEL_VERSION_2, and the corresponding category has a severity score.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String