Entity class final

Represents a phrase in the text that is a known entity, such as a person, an organization, or location. The API associates information, such as probability and mentions, with entities.

Constructors

Entity({String name = '', Entity_Type type = Entity_Type.$default, Map<String, String> metadata = const {}, List<EntityMention> mentions = const [], Sentiment? sentiment})
Entity.fromJson(Object? j)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
mentions → List<EntityMention>
The mentions of this entity in the input document. The API currently supports proper noun mentions.
final
metadata → Map<String, String>
Metadata associated with the entity.
final
name → String
The representative name for the entity.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sentiment → Sentiment?
For calls to AnalyzeEntitySentiment or if AnnotateTextRequest.Features.extract_entity_sentiment is set to true, this field will contain the aggregate sentiment expressed for this entity in the provided document.
final
type → Entity_Type
The entity type.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String