EntityMention class final

Represents a mention for an entity in the text. Currently, proper noun mentions are supported.

Constructors

EntityMention({TextSpan? text, EntityMention_Type type = EntityMention_Type.$default, Sentiment? sentiment, double probability = 0})
EntityMention.fromJson(Object? j)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
probability → double
Probability score associated with the entity.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sentiment → Sentiment?
For calls to AnalyzeEntitySentiment or if AnnotateTextRequest.Features.extract_entity_sentiment is set to true, this field will contain the sentiment expressed for this mention of the entity in the provided document.
final
text → TextSpan?
The mention text.
final
type → EntityMention_Type
The type of the entity mention.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String