ModerateTextRequest class final

The document moderation request message.

Constructors

ModerateTextRequest({required Document? document, ModerateTextRequest_ModelVersion modelVersion = ModerateTextRequest_ModelVersion.$default})
ModerateTextRequest.fromJson(Object? j)
factory

Properties

document → Document?
Required. Input document.
final
hashCode → int
The hash code for this object.
no setterinherited
modelVersion → ModerateTextRequest_ModelVersion
Optional. The model version to use for ModerateText.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String