ModerateTextResponse class final

The document moderation response message.

Constructors

ModerateTextResponse({List<ClassificationCategory> moderationCategories = const [], String languageCode = '', bool languageSupported = false})
ModerateTextResponse.fromJson(Object? j)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
languageCode → String
The language of the text, which will be the same as the language specified in the request or, if not specified, the automatically-detected language. See Document.language field for more details.
final
languageSupported → bool
Whether the language is officially supported. The API may still return a response when the language is not supported, but it is on a best effort basis.
final
moderationCategories → List<ClassificationCategory>
Harmful and sensitive categories representing the input document.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String