TextSpan class final

Represents a text span in the input document.

Constructors

TextSpan({String content = '', int beginOffset = 0})
TextSpan.fromJson(Object? j)
factory

Properties

beginOffset → int
The API calculates the beginning offset of the content in the original document according to the EncodingType specified in the API request.
final
content → String
The content of the text span, which is a substring of the document.
final
hashCode → int
The hash code for this object.
no setterinherited
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String