FakeLanguageService class base
Testing fake for LanguageService.
- Implemented types
Constructors
-
FakeLanguageService({Future<
AnalyzeSentimentResponse> analyzeSentiment(AnalyzeSentimentRequest request)?, Future<AnalyzeEntitiesResponse> analyzeEntities(AnalyzeEntitiesRequest request)?, Future<ClassifyTextResponse> classifyText(ClassifyTextRequest request)?, Future<ModerateTextResponse> moderateText(ModerateTextRequest request)?, Future<AnnotateTextResponse> annotateText(AnnotateTextRequest request)?})
Properties
Methods
-
analyzeEntities(
AnalyzeEntitiesRequest request) → Future< AnalyzeEntitiesResponse> -
Finds named entities (currently proper names and common nouns) in the text
along with entity types, probability, mentions for each entity, and
other properties.
override
-
analyzeSentiment(
AnalyzeSentimentRequest request) → Future< AnalyzeSentimentResponse> -
Analyzes the sentiment of the provided text.
override
-
annotateText(
AnnotateTextRequest request) → Future< AnnotateTextResponse> -
A convenience method that provides all features in one call.
override
-
classifyText(
ClassifyTextRequest request) → Future< ClassifyTextResponse> -
Classifies a document into categories.
override
-
close(
) → void -
Closes the client and cleans up any resources associated with it.
override
-
moderateText(
ModerateTextRequest request) → Future< ModerateTextResponse> -
Moderates a document for harmful and sensitive categories.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited